@@ -2,9 +2,9 @@ import logging
 
 
 def get_logger() -> logging.Logger:
-    """
-    Devuelve el logger de clitellum
+  """
+    Devuelve el logger de atomic
     :return: Logger
     :rtype: logging.Logger
     """
-    return logging.getLogger("clitellum")
+  return logging.getLogger("atomic")
